Graph Learning with JAX
========================
[//]: # (Badges)
[![CI](https://github.com/yuanqing-wang/galax/actions/workflows/CI.yml/badge.svg?branch=main)](https://github.com/yuanqing-wang/galax/actions/workflows/CI.yml)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/yuanqing-wang/galax.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/yuanqing-wang/galax/context:python)
